@@ -9,14 +9,14 @@ use std::sync::{
 
 use log::{error, trace};
 
-pub struct BoundedThreadPool {
+pub struct ThreadPool {
     workers: Vec<Worker>,
     sender: MessageSyncSender,
 }
 
 /// Static thread pool to execute tasks with a fixed number of threads.
-impl BoundedThreadPool {
-    /// Create a new BoundedThreadPool.
+impl ThreadPool {
+    /// Create a new ThreadPool.
     ///
     /// ## Arguments
     /// * `size`: number of threads in the pool.
@@ -24,8 +24,8 @@ impl BoundedThreadPool {
     ///
     /// ## Panics
     /// Function will panic if any parameter is zero.
-    pub fn new(size: usize, max_jobs_queue: usize) -> BoundedThreadPool {
-        trace!("Creating BoundedThreadPool...");
+    pub fn new(size: usize, max_jobs_queue: usize) -> ThreadPool {
+        trace!("Creating ThreadPool...");
         assert!(size > 0);
         assert!(max_jobs_queue > 0);
 
@@ -33,16 +33,16 @@ impl BoundedThreadPool {
         let receiver = Arc::new(Mutex::new(receiver));
         let mut workers = Vec::with_capacity(size);
 
-        trace!("Creating BoundedThreadPool with size {}...", size);
+        trace!("Creating ThreadPool with size {}...", size);
         for id in 0..size {
             workers.push(Worker::new(id, Arc::clone(&receiver)));
         }
-        trace!("BoundedThreadPool created");
+        trace!("ThreadPool created");
 
-        BoundedThreadPool { workers, sender }
+        ThreadPool { workers, sender }
     }
 
-    /// Queues a task for execution in the BoundedThreadPool.
+    /// Queues a task for execution in the ThreadPool.
     pub fn execute<F>(&self, f: F) -> Result<(), ExecuteError>
     where
         F: FnOnce() + Send + 'static,
