@@ -1,10 +1,11 @@
+pub use super::types::ExecuteError;
 use super::{
     types::{Message, MessageSender},
     worker::Worker,
 };
 use std::sync::{mpsc, Arc, Mutex};
 
-use log::trace;
+use log::*;
 
 pub struct ThreadPool {
     workers: Vec<Worker>,
@@ -19,7 +20,7 @@ impl ThreadPool {
     /// * `size`: number of threads in the pool.
     ///
     /// ## Panics
-    /// Function will panic if the size is zero.
+    /// Function will panic if any parameter is zero.
     pub fn new(size: usize) -> ThreadPool {
         trace!("Creating ThreadPool...");
         assert!(size > 0);
@@ -43,6 +44,7 @@ impl ThreadPool {
         F: FnOnce() + Send + 'static,
     {
         let job = Box::new(f);
+
         self.sender.send(Message::NewJob(job)).unwrap();
         trace!("Job added to the queue");
     }
