@@ -1,7 +1,8 @@
-use super::types::{Message, SharedMessageReceiver};
+use crate::types::Message;
+pub use crate::types::{MessageSender, QueueError, SharedMessageReceiver};
 use std::thread;
 
-use log::trace;
+use log::*;
 
 pub struct Worker {
     pub id: usize,
